"use client";
import { useState, useEffect } from "react";
import DataTable from "@/components/tables/DataTable";
import { TableData } from "@/variables/columnsData";
import { DeleteIcon, ViewIcon } from "@chakra-ui/icons";
import { Flex, Button, Icon, useColorModeValue } from "@chakra-ui/react";
import { deleteConsumer, getConsumers } from "@/app/lib/consumer/action";
import useShowToast from "@/app/hooks/useShowToast";
import { useRouter } from "next/navigation";
import { hasPermission } from "@/utils/navigation";
import { useGeneral } from "@/contexts/GeneralContext";
import { columnsDataConsumer } from "../variables/columns";
import Filters from "@/components/filters/Filters";
import { extractPagination } from "@/utils/common";
export interface Consumer {
  id: number;
  name: string;
}
import { MultiSelectOption } from "@/components/fields/MultiSelect";

interface ConsumersTableProps {
  data: { data: TableData[] };
  users: MultiSelectOption[];
  ibcs: MultiSelectOption[];
}

const ConsumersTable: React.FC<ConsumersTableProps> = ({ data, users, ibcs }) => {
  const { currentUser } = useGeneral();
  const brandColor = useColorModeValue("brand.500", "white");
  const router = useRouter();
  const showToast = useShowToast();
  const [loading, setLoading] = useState<number | null>(null);
  const [hasAccess, setHasAccess] = useState<boolean>(true);
  const paginationData = extractPagination(data);

  useEffect(() => {
    const checkUserAccess = () => {
      if (currentUser?.permissions) {
        const userHasPermission = hasPermission(currentUser.permissions, "consumer", "view");
        setHasAccess(userHasPermission);
      } else {
        setHasAccess(false);
      }
    };

  const paginationData = extractPagination(data);

  const handleView = async (id: number) => {
    router.push(`/admin/attempt/consumer/view/${id}`);
  };
  
    checkUserAccess();
  }, [currentUser]);


  const handleView = async (id: number) => {
    router.push(`/admin/attempt/consumer/view/${id}`);
  };

  const handleDelete = async (id: number) => {
    setLoading(id);
    try {
      const response = await deleteConsumer(id);
      if (response.status === false) {
        throw new Error(response.message || "Failed to delete consumer.");
      }
      showToast("Consumer Deleted!", response.message, "success");
      router.refresh();
    } catch (error: any) {
      showToast("Failed to delete", error.message, "error");
    } finally {
      setLoading(null);
    }
  };

  const actions = (id: number) => (
    <Flex gap={2}>
      {hasPermission(currentUser.permissions, "consumer", "view") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => {
            handleView(id);
          }}
          isDisabled={!hasPermission(currentUser.permissions, "consumer", "view")}
        >
          <Icon as={ViewIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}

      {hasPermission(currentUser.permissions, "consumer", "delete") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => {
            handleDelete(id);
          }}
          isDisabled={loading === id || !hasPermission(currentUser.permissions, "consumer", "delete")}
        >
          <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}

    </Flex>
  );


  return (
    <DataTable
      columnsData={columnsDataConsumer}
      tableData={data?.data as TableData[]}
      paginate={paginationData}
      isSelectable={false}
      showPageSize={false}
      showSearch={false}
      actionSlot={actions}
      filterSlot={
        <Filters onExport={getConsumers} users={users} ibcs={ibcs} searchLabel="Contract Account" showBatches={false} />
      }
    />
  );
};

export default ConsumersTable;
